miml package
============

.. automodule:: miml
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4
   :titlesonly:

   miml.classifier
   miml.data
   miml.datasets
   miml.report
   miml.transformation
